==> joounit-0.8.4.jar: joo/classes/flexunit/textui/XmlResultPrinter.js <==
joo.classLoader.prepare("package flexunit.textui",/* {
import flexunit.framework.AssertionFailedError
import flexunit.framework.Test
import flexunit.framework.TestCase
import flexunit.framework.TestFailure
import flexunit.framework.TestListener
import flexunit.framework.TestResult
import flexunit.framework.TestSuite
import flexunit.textui.Printer
import flexunit.utils.ArrayList*/

"public class XmlResultPrinter implements flexunit.framework.TestListener, flexunit.textui.Printer",1,function($$private){var as=joo.as;return[

  "private var",{ resultXml/*:Array*/ : null},
  "private var",{ mTests/*:Array*/ :function(){return( new Array());}},
  "private var",{ mCurrentTest : null},
  "private var",{ mSuite/*:String*/ : null},


  "private var",{ successfullTests/*:Array*/ : null},

  "public function XmlResultPrinter",function XmlResultPrinter$() {this.mTests$1=this.mTests$1();
    this.resultXml$1 = new Array();
    this.successfullTests$1 = new Array();
    this.mTests$1 = new Array();
  },

  "public function addError",function addError(test/* : Test*/, error/* : Error*/)/*:void*/ {
    if (!this.mCurrentTest$1.mError) {
      this.mCurrentTest$1.mError = error;
    }
  },

  "public function addFailure",function addFailure(test/* : Test*/, error/* : AssertionFailedError*/)/*:void*/ {
    if (!this.mCurrentTest$1.mFailure) {
      this.mCurrentTest$1.mFailure = error;
    }
  },

  "public function endTest",function endTest(test/* : Test*/)/*:void*/ {
    if( this.mCurrentTest$1 != null ) {
        var endTime = new Date();
        this.mCurrentTest$1.mTime = endTime - this.mCurrentTest$1.mTime ;
        this.mTests$1.push( this.mCurrentTest$1 );
        this.mCurrentTest$1 = null;
    }

    this.successfullTests$1.push(test);
  },

  "public function startTest",function startTest(test/* : Test*/)/*:void*/ {
    if( this.mSuite$1 == null )
            this.mSuite$1 = test.className;
        this.mCurrentTest$1 = new Object();
        this.mCurrentTest$1.mName = test.className + " " + (as(test,  flexunit.framework.TestCase)).methodName;
        this.mCurrentTest$1.mTime = new Date();

  },
  "public function print",function print(result/*:TestResult*/, runTime/*:Number*/)/*:void*/ {
    this.resultXml$1.push( '<?xml version="1.0" encoding="ISO-8859-1" ?>\n' );
        this.resultXml$1.push( '<testsuite errors="' );
        this.resultXml$1.push( result.errorCount());
        this.resultXml$1.push( '" failures="' );
        this.resultXml$1.push( result.failureCount());
        this.resultXml$1.push( '" name="' );
        this.resultXml$1.push( this.mSuite$1 );
        this.resultXml$1.push( '" tests="' );
        this.resultXml$1.push( result.runCount());
        this.resultXml$1.push( '" time="' );
        this.resultXml$1.push( runTime );
        this.resultXml$1.push( '">\n' );
        for( var i = 0; i < this.mTests$1.length; ++i )
        {
            var test = this.mTests$1[i];
            this.resultXml$1.push( '    <testcase name="' );
            this.resultXml$1.push( test.mName );
            this.resultXml$1.push( '" time="' );
            this.resultXml$1.push( test.mTime );
            this.resultXml$1.push( '"' );
            if( test.mError || test.mFailure )
            {
                this.resultXml$1.push( '>' );
                this.resultXml$1.push( '        <' );
                var defect;
                var tag;
                if( test.mError )
                {
                    defect = test.mError;
                    tag = "error";
                }
                else
                {
                    defect = test.mFailure;
                    tag = "failure";
                }
                this.resultXml$1.push( tag );
                this.resultXml$1.push( ' message="' );
                this.resultXml$1.push( this.escapeXml$1(defect.toString()) );
                this.resultXml$1.push( '" type=""' );

                this.resultXml$1.push( '/' );
                this.resultXml$1.push( '>\n' );
                this.resultXml$1.push( '    </testcase' );
            } else{
                this.resultXml$1.push( '/' );
            }
            this.resultXml$1.push( '>\n' );

        }
        this.resultXml$1.push( '</testsuite>' );

  },

  "private function escapeXml",function escapeXml(str/*:String*/)/*:String*/ {
    var escAmpRegEx = /&/g;
    var escLtRegEx = /</g;
    var escGtRegEx = />/g;
    var quotRegEx = /"/g;
    var aposRegEx = /'/g;
    var result = str.replace(escAmpRegEx, "&amp;").
        replace(escLtRegEx, "&lt;").
        replace(escGtRegEx, "&gt;").
        replace(quotRegEx, "&quot;").
        replace(aposRegEx, "&apos;");

    return result;

  },
  
  "public function getXml",function getXml()/*:String*/ {
    return this.resultXml$1.join("");
  },
];},[],["flexunit.framework.TestListener","flexunit.textui.Printer","Array","Date","Object","flexunit.framework.TestCase"], "0.8.0", "0.8.3"
);

==> joounit-0.9.1.jar: joo/classes/flexunit/textui/XmlResultPrinter.js <==
joo.classLoader.prepare("package flexunit.textui",/* {
import flexunit.framework.AssertionFailedError;
import flexunit.framework.Test;
import flexunit.framework.TestCase;
import flexunit.framework.TestFailure;
import flexunit.framework.TestListener;
import flexunit.framework.TestResult;
import flexunit.framework.TestSuite;
import flexunit.textui.Printer;
import flexunit.utils.ArrayList;*/

"public class XmlResultPrinter implements flexunit.framework.TestListener, flexunit.textui.Printer",1,function($$private){var as=joo.as;return[

  "private var",{ resultXml/*:Array*/ : null},
  "private var",{ mTests/*:Array*/ :function(){return( new Array());}},
  "private var",{ mCurrentTest : null},
  "private var",{ mSuite/*:String*/ : null},


  "private var",{ successfullTests/*:Array*/ : null},

  "public function XmlResultPrinter",function XmlResultPrinter$() {this.mTests$1=this.mTests$1();
    this.resultXml$1 = new Array();
    this.successfullTests$1 = new Array();
    this.mTests$1 = new Array();
  },

  "public function addError",function addError(test/* : Test*/, error/* : Error*/)/*:void*/ {
    if (!this.mCurrentTest$1.mError) {
      this.mCurrentTest$1.mError = error;
    }
  },

  "public function addFailure",function addFailure(test/* : Test*/, error/* : AssertionFailedError*/)/*:void*/ {
    if (!this.mCurrentTest$1.mFailure) {
      this.mCurrentTest$1.mFailure = error;
    }
  },

  "public function endTest",function endTest(test/* : Test*/)/*:void*/ {
    if( this.mCurrentTest$1 != null ) {
        var endTime = new Date();
        this.mCurrentTest$1.mTime = endTime - this.mCurrentTest$1.mTime ;
        this.mTests$1.push( this.mCurrentTest$1 );
        this.mCurrentTest$1 = null;
    }

    this.successfullTests$1.push(test);
  },

  "public function startTest",function startTest(test/* : Test*/)/*:void*/ {
    if( this.mSuite$1 == null )
            this.mSuite$1 = test.className;
        this.mCurrentTest$1 = new Object();
        this.mCurrentTest$1.mName = test.className + " " + (as(test,  flexunit.framework.TestCase)).methodName;
        this.mCurrentTest$1.mTime = new Date();

  },
  "public function print",function print(result/*:TestResult*/, runTime/*:Number*/)/*:void*/ {
    this.resultXml$1.push( '<?xml version="1.0" encoding="ISO-8859-1" ?>\n' );
        this.resultXml$1.push( '<testsuite errors="' );
        this.resultXml$1.push( result.errorCount());
        this.resultXml$1.push( '" failures="' );
        this.resultXml$1.push( result.failureCount());
        this.resultXml$1.push( '" name="' );
        this.resultXml$1.push( this.mSuite$1 );
        this.resultXml$1.push( '" tests="' );
        this.resultXml$1.push( result.runCount());
        this.resultXml$1.push( '" time="' );
        this.resultXml$1.push( runTime );
        this.resultXml$1.push( '">\n' );
        for( var i = 0; i < this.mTests$1.length; ++i )
        {
            var test = this.mTests$1[i];
            this.resultXml$1.push( '    <testcase name="' );
            this.resultXml$1.push( test.mName );
            this.resultXml$1.push( '" time="' );
            this.resultXml$1.push( test.mTime );
            this.resultXml$1.push( '"' );
            if( test.mError || test.mFailure )
            {
                this.resultXml$1.push( '>' );
                this.resultXml$1.push( '        <' );
                var defect;
                var tag;
                if( test.mError )
                {
                    defect = test.mError;
                    tag = "error";
                }
                else
                {
                    defect = test.mFailure;
                    tag = "failure";
                }
                this.resultXml$1.push( tag );
                this.resultXml$1.push( ' message="' );
                this.resultXml$1.push( this.escapeXml$1(defect.toString()) );
                this.resultXml$1.push( '" type=""' );

                this.resultXml$1.push( '/' );
                this.resultXml$1.push( '>\n' );
                this.resultXml$1.push( '    </testcase' );
            } else{
                this.resultXml$1.push( '/' );
            }
            this.resultXml$1.push( '>\n' );

        }
        this.resultXml$1.push( '</testsuite>' );

  },

  "private function escapeXml",function escapeXml(str/*:String*/)/*:String*/ {
    var escAmpRegEx = /&/g;
    var escLtRegEx = /</g;
    var escGtRegEx = />/g;
    var quotRegEx = /"/g;
    var aposRegEx = /'/g;
    var result = str.replace(escAmpRegEx, "&amp;").
        replace(escLtRegEx, "&lt;").
        replace(escGtRegEx, "&gt;").
        replace(quotRegEx, "&quot;").
        replace(aposRegEx, "&apos;");

    return result;

  },
  
  "public function getXml",function getXml()/*:String*/ {
    return this.resultXml$1.join("");
  },
];},[],["flexunit.framework.TestListener","flexunit.textui.Printer","Array","Date","Object","flexunit.framework.TestCase"], "0.8.0", "0.9.1"
);
